%define pypi_name keyring

# Disable as we have too new sphinx
%bcond_with docs

# Disable as don't have
# - pytest-black
# - pytest-ruff
%bcond_with check

Name:		python-%{pypi_name}
Summary:	Python library to access the system keyring service
Version:	25.6.0
Release:	%mkrel 2
Group:		Development/Python
License:	Python
URL:		https://pypi.org/project/keyring/
Source0:	%{pypi_source}
BuildArch:	noarch
BuildRequires:  pyproject-rpm-macros
BuildRequires:  python3-devel

%description
The Python keyring lib provides a easy way to access the system keyring
service from python. It can be used in any application that needs safe
password storage.

This package only provides file-based pseudo-keyrings. To interface with
gnome-keyring or KWallet, please install one of python-keyring-gnome or
python-keyring-kwallet.

%package -n python3-%{pypi_name}
Summary:	Python 3 library to access the system keyring service
Group:		Development/Python
%{?python_provide:%python_provide python3-keyring}

%description -n python3-%{pypi_name}
The Python 3 keyring lib provides a easy way to access the system keyring
service from python 3. It can be used in any application that needs safe
password storage.

This package only provides file-based pseudo-keyrings. To interface with
gnome-keyring or KWallet, please install one of python3-keyring-gnome or
python3-keyring-kwallet.

%prep
%setup -q -n %{pypi_name}-%{version}

%generate_buildrequires
%pyproject_buildrequires %{?with_docs:-x docs} %{?with_check:-x testing}

%build
%pyproject_wheel

%install
%pyproject_install
%pyproject_save_files keyring

# we don't ship tests they need a test environment
rm -rf %{buildroot}%{python3_sitelib}/%{pypi_name}/tests/

%if %{with check}
%check
%pytest
%endif

%files -n python3-keyring -f %{pyproject_files}
%license LICENSE
%doc README.rst NEWS.rst SECURITY.md
%{_bindir}/keyring


%changelog
* Sat Mar 01 2025 daviddavid <daviddavid> 25.6.0-2.mga10
+ Revision: 2154358
- rebuild for python 3.13

* Sat Feb 15 2025 daviddavid <daviddavid> 25.6.0-1.mga10
+ Revision: 2148875
- new version: 25.6.0

* Fri Jun 28 2024 papoteur <papoteur> 25.2.1-1.mga10
+ Revision: 2077600
- new version 25.2.1

* Sun Dec 10 2023 wally <wally> 24.3.0-1.mga10
+ Revision: 2016781
- new version 24.3.0
- use %%pyproject_buildrequires

* Thu Sep 29 2022 neoclust <neoclust> 23.9.3-1.mga9
+ Revision: 1893399
- New version 23.9.3

* Wed Sep 07 2022 neoclust <neoclust> 23.8.2-1.mga9
+ Revision: 1884894
- New version 	23.8.2

* Thu Mar 24 2022 umeabot <umeabot> 23.5.0-3.mga9
+ Revision: 1825038
- Mageia 9 Mass Rebuild

* Thu Feb 24 2022 mrambo3501 <mrambo3501> 23.5.0-2.mga9
+ Revision: 1783912
- rebuild for python-3.10

* Thu Feb 17 2022 akien <akien> 23.5.0-1.mga9
+ Revision: 1779071
- Version 23.5.0

* Sun Mar 21 2021 joequant <joequant> 23.0.0-1.mga9
+ Revision: 1707094
- update to 23.0.0 / python 3.9

* Sun Nov 15 2020 guillomovitch <guillomovitch> 21.5.0-1.mga8
+ Revision: 1646367
- new version 21.5.0

* Wed Sep 09 2020 guillomovitch <guillomovitch> 21.4.0-1.mga8
+ Revision: 1623950
- new version 21.4.0

* Tue Apr 28 2020 daviddavid <daviddavid> 21.2.0-1.mga8
+ Revision: 1572827
- new version: 21.2.0

* Thu Feb 20 2020 umeabot <umeabot> 21.1.0-2.mga8
+ Revision: 1546113
- Mageia 8 Mass Rebuild

* Wed Feb 19 2020 daviddavid <daviddavid> 21.1.0-1.mga8
+ Revision: 1543871
- new version: 21.1.0

* Fri Jan 31 2020 daviddavid <daviddavid> 21.0.0-1.mga8
+ Revision: 1485967
- new version: 21.0.0

* Thu Dec 12 2019 daviddavid <daviddavid> 19.3.0-1.mga8
+ Revision: 1466058
- new version: 19.3.0

* Wed Oct 09 2019 daviddavid <daviddavid> 19.2.0-1.mga8
+ Revision: 1450808
- new version: 19.2.0

* Sun Sep 22 2019 daviddavid <daviddavid> 19.0.1-2.mga8
+ Revision: 1444625
- rebuild for python3.8

* Fri Apr 19 2019 wally <wally> 19.0.1-1.mga8
+ Revision: 1393486
- new version 19.0.1
- drop python2 support

* Tue Jan 08 2019 tv <tv> 8.5.1-5.mga7
+ Revision: 1351615
- rebuild with python 3.7

* Thu Sep 20 2018 umeabot <umeabot> 8.5.1-4.mga7
+ Revision: 1289162
- Mageia 7 Mass Rebuild

* Wed Oct 04 2017 pterjan <pterjan> 8.5.1-3.mga7
+ Revision: 1168909
- Fix buildrequires
+ tv <tv>
- add BR on python2dist(setuptools_scm) thus fixing build

* Sat Aug 05 2017 pterjan <pterjan> 8.5.1-2.mga7
+ Revision: 1135473
- Rebuild for python 3.6

* Sun Mar 27 2016 philippem <philippem> 8.5.1-1.mga6
+ Revision: 995780
- update to 8.5.1

* Tue Feb 16 2016 philippem <philippem> 8.4.1-1.mga6
+ Revision: 962675
- remove no longer need sed
- update to 8.4.1

* Sat Dec 12 2015 philippem <philippem> 5.7-1.mga6
+ Revision: 909726
- fix docs
- update to 5.7

* Wed Oct 28 2015 philippem <philippem> 5.6-1.mga6
+ Revision: 896123
- update to 5.6

* Sat Oct 10 2015 tv <tv> 4.0-5.mga6
+ Revision: 888806
- rebuild for python 3.5

* Wed Oct 15 2014 umeabot <umeabot> 4.0-4.mga5
+ Revision: 741897
- Second Mageia 5 Mass Rebuild

* Sat Sep 27 2014 tv <tv> 4.0-3.mga5
+ Revision: 728934
- rebuild for missing pythoneggs deps

* Tue Sep 16 2014 umeabot <umeabot> 4.0-2.mga5
+ Revision: 688109
- Mageia 5 Mass Rebuild
+ ovitters <ovitters>
- add gobject-introspection BR for typelib auto BR

* Tue Aug 12 2014 philippem <philippem> 4.0-1.mga5
+ Revision: 662100
- update to 4.0

* Sat May 31 2014 pterjan <pterjan> 3.8-2.mga5
+ Revision: 628735
- Rebuild for new Python

* Sun May 18 2014 philippem <philippem> 3.8-1.mga5
+ Revision: 623630
- update to 3.8

* Sun Mar 30 2014 philippem <philippem> 3.7-1.mga5
+ Revision: 610458
- update to 3.7

* Thu Mar 06 2014 philippem <philippem> 3.6-1.mga5
+ Revision: 600515
- update to 3.6

* Sat Nov 02 2013 fwang <fwang> 3.0.5-4.mga4
+ Revision: 548944
- add requires

* Tue Oct 22 2013 umeabot <umeabot> 3.0.5-3.mga4
+ Revision: 543702
- Mageia 4 Mass Rebuild

* Tue Oct 15 2013 pterjan <pterjan> 3.0.5-2.mga4
+ Revision: 498821
- Rebuild to add different pythonegg provides for python 2 and 3

* Thu Oct 03 2013 philippem <philippem> 3.0.5-1.mga4
+ Revision: 490632
- Update to 3.0.5

* Sun Sep 01 2013 philippem <philippem> 2.1.1-1.mga4
+ Revision: 474028
- update to 2.1.1

* Thu Jul 18 2013 philippem <philippem> 1.6-1.mga4
+ Revision: 455965
- Update to 1.6

* Sat Jun 08 2013 philippem <philippem> 1.4-1.mga4
+ Revision: 440641
- add python3

* Sat Jun 08 2013 philippem <philippem> 1.4-0.mga4
+ Revision: 440608
- disable python3 now seems that there are problems with 3.3 should be fixed in next upstream
- imported package python-keyring

